"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ZipDataDir = exports.GetVersion = exports.SendServerMessage = exports.ConfigureAuthorizationHeaderFromUserPassword = exports.ConfigureAuthorizationHeader = exports.ConfigureServerURL = void 0;
var needle_1 = __importDefault(require("needle"));
var message_util_1 = require("./util/message-util");
var validation_util_1 = require("./util/validation-util");
var SERVER_URL = 'http://localhost:9999/'; // default to bitcoin-s server
var AUTHORIZATION_HEADER = ''; // default to no auth
/** Set Wallet Server endpoint */
function ConfigureServerURL(url) {
    console.debug('ConfigureServerURL()', url);
    SERVER_URL = url;
}
exports.ConfigureServerURL = ConfigureServerURL;
/** Set Wallet Server Authorization header */
function ConfigureAuthorizationHeader(header) {
    console.debug('ConfigureAuthorizationHeader()', header);
    AUTHORIZATION_HEADER = header;
}
exports.ConfigureAuthorizationHeader = ConfigureAuthorizationHeader;
// Convenience function
function ConfigureAuthorizationHeaderFromUserPassword(user, password) {
    console.debug('ConfigureAuthorizationHeader()', user);
    AUTHORIZATION_HEADER = 'Basic ' + Buffer.from("".concat(user, ":").concat(password)).toString('base64');
}
exports.ConfigureAuthorizationHeaderFromUserPassword = ConfigureAuthorizationHeaderFromUserPassword;
/** Send any ServerMessage */
function SendServerMessage(message) {
    if (message) {
        var options = { json: true };
        if (AUTHORIZATION_HEADER)
            options.headers = { 'Authorization': AUTHORIZATION_HEADER };
        return (0, needle_1.default)('post', "".concat(SERVER_URL), message, options).then(function (response) {
            var body = response.body;
            // Throw backend error to break promise chain for catch handling
            if (body.error)
                throw (body.error);
            return body;
        }).catch(function (err) {
            console.error('SendServerMessage() error', err);
            throw (err);
        });
    }
    else {
        throw (Error('SendServerMessage() null message'));
    }
}
exports.SendServerMessage = SendServerMessage;
/** Common bitcoin-s message functions */
function GetVersion() {
    console.debug('GetVersion()');
    var m = (0, message_util_1.getMessageBody)("getversion" /* getversion */);
    return SendServerMessage(m).then(function (response) {
        return response;
    });
}
exports.GetVersion = GetVersion;
function ZipDataDir(path) {
    console.debug('ZipDataDir()');
    (0, validation_util_1.validateString)(path, 'ZipDataDir()', 'path');
    var m = (0, message_util_1.getMessageBody)("zipdatadir" /* zipdatadir */, [path]);
    return SendServerMessage(m).then(function (response) {
        // result: 'failure' / null
        return response;
    });
}
exports.ZipDataDir = ZipDataDir;
// export default [ConfigureWalletServerURL, SendOracleMessage, GetVersion]
